/*
UNIVERSITE PARIS 1 (PANTHEON SORBONNE)
MIAGE - UFR 27
Cours ISI5 / INF2 - Developpement d'Interface
 */
package review.exercices;

import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import javax.swing.DefaultListModel;
import javax.swing.JButton;
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JList;
import javax.swing.JScrollPane;
import javax.swing.JTextField;
import javax.swing.ListSelectionModel;
import javax.swing.event.ListSelectionEvent;
import javax.swing.event.ListSelectionListener;

/**
 * Frame pour l'edition d'un ensemble de proprietes
 * @author kirsch
 */
public class PropertiesEditorFrame extends JFrame {

    JList propList;
    JTextField keyField;
    JTextField valueField;
    JButton newBtn;
    JButton changeBtn;
    JButton removeBtn;
    String[] actionCmds;
    ActionListener btnListener;
    ListSelectionListener lstListener;

    public PropertiesEditorFrame(String title) {
        super(title);

        loadDefaultActionCmds();
        initComponents();
    }

    public PropertiesEditorFrame() {
        this("");
    }

    private void initComponents() {
        this.propList = new JList(new DefaultListModel());
        this.keyField = new JTextField(15);
        this.valueField = new JTextField(15);
        this.newBtn = new JButton("New");
        this.changeBtn = new JButton("Change");
        this.removeBtn = new JButton("Remove");

        placeComponents();

        this.propList.setSelectionMode(ListSelectionModel.SINGLE_SELECTION);

        setActionCmds();

        setActionListener();
        setListSelectionListener();
    }

    private void loadDefaultActionCmds() {
        this.actionCmds = new String[3];
        this.actionCmds[0] = "newProp";
        this.actionCmds[1] = "changeProp";
        this.actionCmds[2] = "removeProp";
    }

    private void placeComponents() {
        this.setLayout(new GridBagLayout());
        GridBagConstraints c = new GridBagConstraints();

        c.fill = GridBagConstraints.HORIZONTAL;
        c.gridx = 1;
        c.gridy = 0;
        this.add(new JLabel("Key"), c);

        c.gridx = 2;
        c.gridy = 0;
        this.add(this.keyField, c);

        c.gridx = 1;
        c.gridy = 2;
        this.add(new JLabel("Value"), c);

        c.gridx = 2;
        c.gridy = 2;
        this.add(this.valueField, c);

        c.gridx = 0;
        c.gridy = 3;
        this.add(this.newBtn, c);

        c.gridx = 1;
        c.gridy = 3;
        this.add(this.changeBtn, c);

        c.gridx = 2;
        c.gridy = 3;
        this.add(this.removeBtn, c);

        c.fill = GridBagConstraints.VERTICAL;
        c.anchor = GridBagConstraints.EAST;
        c.gridx = 0;
        c.gridy = 0;
        c.gridheight = 3;
        c.weighty = 0.5;
        JScrollPane scroll = new JScrollPane(this.propList);
        this.add(scroll, c);

        this.pack();
    }

    public String[] getActionCmds() {
        return actionCmds;
    }

    public void setActionCmds(String[] actionCmds) {
        if (actionCmds.length >= 3) {
            this.actionCmds = actionCmds;
            setActionCmds();
        }
    }

    private void setActionCmds() {
        this.newBtn.setActionCommand(this.actionCmds[0]);
        this.changeBtn.setActionCommand(this.actionCmds[1]);
        this.removeBtn.setActionCommand(this.actionCmds[2]);
    }

    public ActionListener geActionListener() {
        return btnListener;
    }

    public void setActionListener(ActionListener listener) {
        this.btnListener = listener;
        setActionListener();
    }

    private void setActionListener() {
        this.newBtn.addActionListener(btnListener);
        this.changeBtn.addActionListener(btnListener);
        this.removeBtn.addActionListener(btnListener);
    }

    public ListSelectionListener getListSelectionListener() {
        return lstListener;
    }

    public void setListSelectionListener(ListSelectionListener lstListener) {
        this.lstListener = lstListener;
        setListSelectionListener();
    }
    
   private void setListSelectionListener() {
       this.propList.addListSelectionListener(lstListener);
   }

    public void setListItems(String[] items) {
        DefaultListModel lmodel = (DefaultListModel) this.propList.getModel();
        lmodel.clear();
        for (String prop : items) {
            lmodel.addElement(prop);
        }

        this.pack();
    }

    public String[] getListItems() {
        DefaultListModel lmodel = (DefaultListModel) this.propList.getModel();
        String[] items = new String[lmodel.size()];
        lmodel.copyInto(items);
        return items;
    }

    public void addListItem(String item) {
        DefaultListModel lmodel = (DefaultListModel) this.propList.getModel();
        lmodel.addElement(item);
    }

    public void removeListItem(String item) {
        DefaultListModel lmodel = (DefaultListModel) this.propList.getModel();
        if (lmodel.contains(item)) {
            lmodel.removeElement(item);
        }
    }

    public String getSelectedItem() {
        int index = this.propList.getSelectedIndex();
        DefaultListModel lmodel = (DefaultListModel) this.propList.getModel();

        String item = (String) lmodel.getElementAt(index);
        return item;
    }

    public String getKeyField () {
        return this.keyField.getText();
    }

    public void setKeyField(String text) {
        this.keyField.setText(text);
    }

    public String getValueField () {
        return this.valueField.getText();
    }

    public void setValueField(String text) {
        this.valueField.setText(text);
    }

    public static void main(String args[]) {
        final PropertiesEditorFrame frame = new PropertiesEditorFrame();
        String[] actions = {"new", "change", "remove"};
        String[] items = {"key1", "key2", "key3"};

        frame.setActionCmds(actions);
        frame.setListItems(items);

        frame.setActionListener(new ActionListener() {

            public void actionPerformed(ActionEvent e) {
                System.out.println(e.getActionCommand());
                if (e.getActionCommand().equals("remove"))
                        System.out.println("REMOVE!!!");
            }
        });

        frame.setListSelectionListener(new ListSelectionListener() {
            public void valueChanged(ListSelectionEvent e) {
                String key = frame.getSelectedItem();
                frame.setKeyField(key);
            }
        });

        frame.setDefaultCloseOperation(JFrame.DISPOSE_ON_CLOSE);
        frame.setVisible(true);

    }

    
}
