/*
 UNIVERSITE PARIS 1 (PANTHEON SORBONNE)
 MIAGE - UFR 27
 Cours ISI5 / INF2 - Developpement d'Interface

 */

package review.properties;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.util.Enumeration;
import java.util.Properties;
import java.util.Scanner;
import java.util.logging.Level;
import java.util.logging.Logger;

/**
 * Exemple d'usage des properties pour le stockage des donnes de configuration
 * @author kirsch
 */
public class SimplePropertiesDemo {

    static String DEFAULT_USER_NAME_KEY = "user.name";
    static String DEFAULT_USER_NAME_VALUE = "";
    static String DEFAULT_USER_CITY_KEY = "user.city";
    static String DEFAULT_USER_CITY_VALUE = "somewhere";

    static Properties loadDefaultProperties() {
        Properties defaultsettings = new Properties();
        defaultsettings.put(DEFAULT_USER_NAME_KEY, DEFAULT_USER_NAME_VALUE);
        defaultsettings.put(DEFAULT_USER_CITY_KEY, DEFAULT_USER_CITY_VALUE);
        return (defaultsettings);
    }


    static Properties loadProperties (String path, Properties defaultsettings) {
        Properties settings = new Properties(defaultsettings);
        File propfile = new File(path);
        if (propfile.exists()) {
            try {
                FileInputStream in = new FileInputStream(propfile);
                settings.load(in);
            } catch (FileNotFoundException ex) {
                Logger.getLogger(SimplePropertiesDemo.class.getName()).log(Level.SEVERE,
                        "Impossible d'ouvrir fichier de propriete", ex);
            } catch (IOException ioex) {
                Logger.getLogger(SimplePropertiesDemo.class.getName()).log(Level.SEVERE,
                        "Impossible de lire le fichier de propriete", ioex);
            }
        }
        return settings;
    }

    static void storeProperties (String path, String comment, Properties settings) {
        File propfile = new File(path);

        try {
            FileOutputStream out = new FileOutputStream(propfile);
            settings.store(out, comment);
        } catch (FileNotFoundException ex) {
            Logger.getLogger(SimplePropertiesDemo.class.getName()).log(Level.SEVERE,
                    "Impossible d'ouvrir fichier de propriete", ex);
        } catch (IOException ioex) {
            Logger.getLogger(SimplePropertiesDemo.class.getName()).log(Level.SEVERE,
                    "Impossible d'enregistrer fichier de propriete", ioex);
        }
    }


    static String findSettingsFilePath () {
        String path;
        String dir=System.getProperty("user.dir", ".");
        String file = SimplePropertiesDemo.class.getSimpleName() + ".properties";
        String separator = System.getProperty("file.separator", "/");

        path = dir + separator + file;
        return (path);
    }

    static void printSettings (Properties settings) {
        Enumeration keys = settings.propertyNames();
        while (keys.hasMoreElements()) {
            String aKey = (String) keys.nextElement();
            String value = settings.getProperty(aKey);

            System.out.println (aKey + "=" + value);
        }
    }

    static String readProperty (String message) {
        String value = "";

        Scanner in = new Scanner(System.in);
        System.out.print(message);
        value = in.nextLine();

        return (value);
    }

    static void setProperties (Properties settings) {
        Enumeration keys = settings.propertyNames();
        while (keys.hasMoreElements()) {
            String aKey = (String) keys.nextElement();
            String value = readProperty(aKey+": ");
            settings.put(aKey, value);
        }
    }


    /**
     * @param args the command line arguments
     */
    public static void main(String[] args) {
        Properties defaultsettings = loadDefaultProperties();
        String path = findSettingsFilePath();
        Properties settings = loadProperties(path, defaultsettings);

        System.out.println("Loaded properties");
        printSettings(settings);

        setProperties(settings);

        System.out.println ("Saving properties into "+path);
        storeProperties(path, "SimplePropertiesDemo", settings);
    }

}
